==> cramr_ui_lib-1.0.16.tar.gz: test/routes/learn_or_repeat_route_test.dart <==
import 'package:cramr_ui_lib/ads/ads_controller.dart';
import 'package:cramr_ui_lib/ads/safe_banner_ad_widget.dart';
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/learn_or_repeat_route.dart';
import 'package:cramr_ui_lib/settings/notification_service.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';
const String _mode = 'mode';
const String _tense = 'tense';

void main() {
  testWidgets('basic test of learn or repeat route',
      (WidgetTester tester) async {
    SharedPreferences.setMockInitialValues(<String, Object>{'counter': 1});
    SharedPreferences prefs = await SharedPreferences.getInstance();
    AdsController? adsController = AdsController(MobileAds.instance);
    await tester.pumpWidget(MultiProvider(
        providers: [
          ChangeNotifierProvider(
            create: (BuildContext context) {
              var model = VerbTestModel();
              model.initialise(_randomIndicative, _randomPronouns,
                  _randomInfinitive, 'fr', 'translation', _mode, _tense);
              int i = 0;
              for (var element in _randomIndicative) {
                model.add(element, i++);
              }
              return model;
            },
          ),
          Provider<AdsController?>(
            create: (BuildContext context) {
              return adsController;
            },
          )
        ],
        child: MaterialApp(
          home: LearnOrRepeatRoute(
            safeBannerAdWidget: const SafeBannerAdWidget(
              adUnitId: '',
              adRequest: AdRequest(),
            ),
            settingsController: SettingsController(SettingsService(prefs),
                ThemeMode.dark, prefs, NotificationService()),
          ),
        )));
    Finder learnOrRepeatListViewFinder =
        find.byKey(const Key('LearnOrRepeatListView'));
    await tester.pumpAndSettle(const Duration(seconds: 1));
    expect(learnOrRepeatListViewFinder, findsOneWidget);

    Finder findButtonFinder = find.byKey(const Key('learn_key'));
    expect(findButtonFinder, findsOneWidget);
  });
}

==> cramr_ui_lib-2.0.0.tar.gz: test/routes/learn_or_repeat_route_test.dart <==
import 'package:cramr_ui_lib/ads/ads_controller.dart';
import 'package:cramr_ui_lib/ads/safe_banner_ad_widget.dart';
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/learn_or_repeat_route.dart';
import 'package:cramr_ui_lib/settings/client_context.dart';
import 'package:cramr_ui_lib/settings/notification_service.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';
const String _mode = 'mode';
const String _tense = 'tense';

void main() {
  testWidgets('basic test of learn or repeat route',
      (WidgetTester tester) async {
    SharedPreferences.setMockInitialValues(<String, Object>{'counter': 1});
    SharedPreferences prefs = await SharedPreferences.getInstance();
    AdsController? adsController = AdsController(MobileAds.instance);
    await tester.pumpWidget(MultiProvider(
        providers: [
          ChangeNotifierProvider(
            create: (BuildContext context) {
              var model = VerbTestModel();
              model.initialise(_randomIndicative, _randomPronouns,
                  _randomInfinitive, 'fr', 'translation', _mode, _tense);
              int i = 0;
              for (var element in _randomIndicative) {
                model.add(element, i++);
              }
              return model;
            },
          ),
          Provider<AdsController?>(
            create: (BuildContext context) {
              return adsController;
            },
          )
        ],
        child: MaterialApp(
          home: LearnOrRepeatRoute(
            safeBannerAdWidget: const SafeBannerAdWidget(
              adUnitId: '',
              adRequest: AdRequest(),
            ),
            settingsController: SettingsController(
                SettingsService(prefs),
                ThemeMode.dark,
                prefs,
                NotificationService(),
                ClientContext(ClientApp.verbomatiqueSecondaire)),
          ),
        )));
    Finder learnOrRepeatListViewFinder =
        find.byKey(const Key('LearnOrRepeatListView'));
    await tester.pumpAndSettle(const Duration(seconds: 1));
    expect(learnOrRepeatListViewFinder, findsOneWidget);

    Finder findButtonFinder = find.byKey(const Key('learn_key'));
    expect(findButtonFinder, findsOneWidget);
  });
}
